@@ -1,3 +1,4 @@
+import os
 from concurrent.futures import ThreadPoolExecutor, as_completed
 
 from .core import Authentication
@@ -6,11 +7,19 @@ from .endpoint import GetSearchableMailboxes, GetUserSettings, ResolveNames, Sea
 
 class EWS:
 
-    def __init__(self, username, password, endpoints=None, exchange_version=None, impersonate_as=None, multi_threading=False):
+    def __init__(self, 
+        username, password, ews_url=None, exchange_version=None, impersonate_as=None, multi_threading=False, 
+        tenant_id=None, client_id=None, client_secret=None, oauth2_authorization_type='auth_code_grant', redirect_uri=None, oauth2_scope=None):
         Authentication.credentials = (username, password)
-        Authentication.endpoints = endpoints
+        Authentication.ews_url = ews_url
         Authentication.exchange_versions = exchange_version
         Authentication.impersonate_as = impersonate_as
+        Authentication.tenant_id = tenant_id
+        Authentication.client_id = client_id
+        Authentication.client_secret = client_secret
+        Authentication.oauth2_authorization_type = oauth2_authorization_type
+        Authentication.redirect_uri = redirect_uri
+        Authentication.oauth2_scope = oauth2_scope
         self.multi_threading = multi_threading
 
     def chunk(self, items, n):
@@ -32,7 +41,7 @@ class EWS:
     def __execute_multithreaded_search(self, query, reference_id, scope):
         return SearchMailboxes(query=query, reference_id=reference_id, search_scope=scope).run()
 
-    def execute_ews_search(self, query, reference_id, search_scope='All', thread_count=10):
+    def execute_ews_search(self, query, reference_id, search_scope='All', thread_count=os.cpu_count()*5):
         response = []
         return_list = []
         if self.multi_threading:
@@ -109,7 +118,7 @@ class EWS:
         for item in item_id:
             deleted_item = DeleteItem(item, delete_type=delete_type).run()
 
-    def search_and_delete_message(self, query, thread_count=10, what_if=False):
+    def search_and_delete_message(self, query, thread_count=os.cpu_count()*5, what_if=False):
         reference_id_list = []
         for mailbox in self.get_searchable_mailboxes():
             reference_id_list.append(mailbox.get('reference_id'))
