@@ -99,7 +99,7 @@ class Base(Core):
                     setattr(self, item, getattr(Authentication, item))
 
         for version in Authentication.exchange_versions:
-            for endpoint in Authentication.endpoints:
+            for endpoint in Authentication.ews_url:
                 if self.__class__.__base__.__name__ == 'Operation' and 'autodiscover' in endpoint:
                     self.__logger.debug('{} == Operation so skipping endpoint {}'.format(self.__class__.__base__.__name__, endpoint))
                     continue
@@ -111,10 +111,16 @@ class Base(Core):
                     self.__logger.info('Setting Exchange Version header to {}'.format(version))
                     body = self.get(version).decode("utf-8")
                     self.__logger.debug('EWS SOAP Request Body: {}'.format(body))
+                    if Authentication.auth_header:
+                        header_dict = Authentication.auth_header
+                        header_dict.update(self.SOAP_REQUEST_HEADER)
+                    else:
+                        header_dict = self.SOAP_REQUEST_HEADER
+                    self.__logger.debug(f"Headers: {header_dict}")
                     response = requests.post(
                         url=endpoint,
                         data=body,
-                        headers=self.SOAP_REQUEST_HEADER,
+                        headers=header_dict,
                         auth=Authentication.credentials,
                         verify=True
                     )
